<?php

namespace Drupal\micro_site\Plugin\Validation\Constraint;

use Drupal\Component\Utility\Unicode;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates that the site url is unique and valid for the given entity type.
 */
class SiteUrlFieldValueValidator extends ConstraintValidator {

  /**
   * {@inheritdoc}
   */
  public function validate($entity, Constraint $constraint) {
    /** @var  \Drupal\micro_site\entity\SiteInterface $entity */
    if (!$entity->isNew()) {
      return;
    }

    $site_url = $entity->site_url->value;
    $type_url = $entity->type_url->value;
    $base_url = $entity::getHostBaseUrl();
    switch ($type_url) {
      case 'subdomain':
        $error = FALSE;
        // check pattern.
        $pattern = '/^[a-z0-9\-]*$/';
        if (!preg_match($pattern, $site_url)) {
          $error = TRUE;
        }

        // Check for lower case.
        if ($site_url != Unicode::strtolower($site_url)) {
          $error = TRUE;
        }

        if ($error) {
          $this->context->addViolation($constraint->message_sub_domain, [
            '%value' => $site_url,
          ]);
        }

        // Check existing site.
        $complete_url = $site_url . '.' .$base_url;
        $existing = \Drupal::entityTypeManager()->getStorage('site')->loadByProperties(['site_url' => $complete_url]);
        $existing = reset($existing);
        if ($existing) {
          $this->context->addViolation($constraint->message, [
            '%value' => $site_url,
          ]);
        }

        // Check reserved keywords.
        $keywords = ['host', 'localhost', 'www'];
        if (in_array($site_url, $keywords)) {
          $this->context->addViolation($constraint->message_reserved, [
            '%value' => $site_url,
          ]);
        }
        break;

      case 'domain':
        $error = FALSE;
        // check pattern.
        $pattern = '/^([a-z0-9\-]*)\.([a-z0-9]*)\.([a-z\.]{1,7}[a-z])$/';
        if (!preg_match($pattern, $site_url)) {
          $error = TRUE;
        }

        if ($error) {
          $this->context->addViolation($constraint->message_domain, [
            '%value' => $site_url,
          ]);
        }

        // Check existing site.
        $existing = \Drupal::entityTypeManager()->getStorage('site')->loadByProperties(['site_url' => $site_url]);
        $existing = reset($existing);
        if ($existing) {
          $this->context->addViolation($constraint->message, [
            '%value' => $site_url,
          ]);
        }
        break;

      default:
        break;
    }
  }

}
