<?php

namespace Drupal\micro_site\Plugin\Validation\Constraint;

use Drupal\Component\Utility\Unicode;
use Drupal\Core\Url;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates that a field is unique for the given entity type.
 */
class SubDomainSiteUrlFieldValueValidator extends ConstraintValidator {

  /**
   * {@inheritdoc}
   */
  public function validate($items, Constraint $constraint) {
    if (!$item = $items->first()) {
      return;
    }
    $field_name = $items->getFieldDefinition()->getName();
    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    $entity = $items->getEntity();
    $entity_type_id = $entity->getEntityTypeId();
    $id_key = $entity->getEntityType()->getKey('id');

    $site_url = $item->value;

    // Check for valid characters, unless using non-ASCII domains.
    $error = FALSE;
    $pattern = '/^[a-z0-9\-]*$/';
    if (!preg_match($pattern, $site_url)) {
      $error = TRUE;
    }

    // Check for lower case.
    if ($site_url != Unicode::strtolower($site_url)) {
      $error = TRUE;
    }

    if ($error) {
      $this->context->addViolation($constraint->message, [
        '%value' => $item->value,
      ]);
    }



  }

}
